==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/RequiredOperationBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredOperationSetImpl;

import java.util.Arrays;
import java.util.List;


public class RequiredOperationBodySetImpl extends InstanceSet<RequiredOperationBodySet,RequiredOperationBody> implements RequiredOperationBodySet {

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( RequiredOperationBody requiredoperationbody : this ) requiredoperationbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredOperationBody requiredoperationbody : this ) requiredoperationbody.setId( ref_Id );
    }


    // selections
    @Override
    public RequiredOperationSet R685_specifies_processing_for_RequiredOperation() throws XtumlException {
        RequiredOperationSet requiredoperationset = new RequiredOperationSetImpl();
        for ( RequiredOperationBody requiredoperationbody : this ) requiredoperationset.add( requiredoperationbody.R685_specifies_processing_for_RequiredOperation() );
        return requiredoperationset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( RequiredOperationBody requiredoperationbody : this ) bodyset.add( requiredoperationbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public RequiredOperationBody nullElement() {
        return RequiredOperationBodyImpl.EMPTY_REQUIREDOPERATIONBODY;
    }

    @Override
    public RequiredOperationBodySet emptySet() {
      return new RequiredOperationBodySetImpl();
    }

    @Override
    public RequiredOperationBodySet value() {
        return this;
    }

    @Override
    public List<RequiredOperationBody> elements() {
        return Arrays.asList(toArray(new RequiredOperationBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/RequiredOperationBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredOperationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class RequiredOperationBodySetImpl extends InstanceSet<RequiredOperationBodySet,RequiredOperationBody> implements RequiredOperationBodySet {

    public RequiredOperationBodySetImpl() {
    }

    public RequiredOperationBodySetImpl(Comparator<? super RequiredOperationBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( RequiredOperationBody requiredoperationbody : this ) requiredoperationbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredOperationBody requiredoperationbody : this ) requiredoperationbody.setId( ref_Id );
    }


    // selections
    @Override
    public RequiredOperationSet R685_specifies_processing_for_RequiredOperation() throws XtumlException {
        RequiredOperationSet requiredoperationset = new RequiredOperationSetImpl();
        for ( RequiredOperationBody requiredoperationbody : this ) requiredoperationset.add( requiredoperationbody.R685_specifies_processing_for_RequiredOperation() );
        return requiredoperationset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( RequiredOperationBody requiredoperationbody : this ) bodyset.add( requiredoperationbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public RequiredOperationBody nullElement() {
        return RequiredOperationBodyImpl.EMPTY_REQUIREDOPERATIONBODY;
    }

    @Override
    public RequiredOperationBodySet emptySet() {
      return new RequiredOperationBodySetImpl();
    }

    @Override
    public RequiredOperationBodySet emptySet(Comparator<? super RequiredOperationBody> comp) {
      return new RequiredOperationBodySetImpl(comp);
    }

    @Override
    public RequiredOperationBodySet value() {
        return this;
    }

    @Override
    public List<RequiredOperationBody> elements() {
        return Arrays.asList(toArray(new RequiredOperationBody[0]));
    }

}
